/*********************************************************************************
*  KeyboardHandler
*
*  Author:				Joshua Phillips [jawsh@u.washington.edu]
*
*  Date:				02-27-06
*
*  Acknowledgements:	Credit to Chris D'Annunzio for the DirectInput Tutorial
*
*  Description:			Suppors Direct Input and polling of the keyboard through
*						a simple interface.
*
*  Example:				//in header file of main dialog
*						private:
*							CKeyboardHandler m_KeyboardHandler
*
*						//in OnInit() function of main dialog
*                       m_KeyboardHandler.Initialize( this->m_hWnd );
*
*						//at beginning of OnTimer() function of main dialog
*						m_KeyboardHandler.PollKeyboardState();
*						if( m_KeyboardHandler.KeyDown( DIK_LEFT ) ) {
*							UWB_EchoToStatusArea( L"Left Arrow Pressed!" );
*						}
*						if( m_KeyboardHandler.KeyDown( DIK_SPACE ) ) {
*							UWB_EchoToStatusArea( L"Space Bar Pressed!" );
*						}
*********************************************************************************/
#include "StdAfx.h"
#include "KeyboardHandler.h"

CKeyboardHandler::CKeyboardHandler()
{
}

CKeyboardHandler::~CKeyboardHandler()
{
}

bool CKeyboardHandler::Initialize( HWND windowHandle )
{
	// Create the abstract DirectInput connection
	DirectInput8Create(	GetModuleHandle(NULL), DIRECTINPUT_VERSION,	IID_IDirectInput8, (void**)&fDI, NULL);
	if (fDI == NULL)
	{
		return false;
	}
	// Create the connection to the keyboard device
	fDI->CreateDevice(GUID_SysKeyboard, &fDIKeyboard, NULL);
	if (fDIKeyboard)
	{
		fDIKeyboard->SetDataFormat(&c_dfDIKeyboard);
		fDIKeyboard->SetCooperativeLevel( windowHandle, DISCL_FOREGROUND | DISCL_EXCLUSIVE );
		fDIKeyboard->Acquire();
	}
	else
	{
		return false;
	}
		return true;
}

void CKeyboardHandler::PollKeyboardState()
{
	HRESULT hr;
	// get the keyboard state
	hr = fDIKeyboard->GetDeviceState( sizeof(fDIKeyboardState), (LPVOID)&fDIKeyboardState);
	if (FAILED(hr))
	{
		// The keyboard was lost so clear out the state
		ZeroMemory(fDIKeyboardState, sizeof(fDIKeyboardState));

		// It's possible that we lost access to the keyboard
		// Here we acquire access to the keyboard again
		fDIKeyboard->Acquire();
		return;
	}
}

bool CKeyboardHandler::KeyDown( int key )
{
	// The following macro allows you to test if
	// a key is currently pressed
	#define KEYDOWN(name, key) (name[key] & 0x80)	
	return (KEYDOWN(fDIKeyboardState, key) != 0);
}