/*********************************************************************************
*  KeyboardHandler
*
*  Author:				Joshua Phillips [jawsh@u.washington.edu]
*
*  Date:				02-27-06
*
*  Acknowledgements:	Credit to Chris D'Annunzio for the DirectInput Tutorial
*
*  Description:			Suppors Direct Input and polling of the keyboard through
*						a simple interface.
*
*  Example:				//in header file of main dialog
*						private:
*							CKeyboardHandler m_KeyboardHandler
*
*						//in OnInit() function of main dialog
*                       m_KeyboardHandler.Initialize( this->m_hWnd );
*
*						//at beginning of OnTimer() function of main dialog
*						m_KeyboardHandler.PollKeyboardState();
*						if( m_KeyboardHandler.KeyDown( DIK_LEFT ) ) {
*							UWB_EchoToStatusArea( L"Left Arrow Pressed!" );
*						}
*						if( m_KeyboardHandler.KeyDown( DIK_SPACE ) ) {
*							UWB_EchoToStatusArea( L"Space Bar Pressed!" );
*						}
*********************************************************************************/
#pragma once
#define DIRECTINPUT_VERSION 0x0800
#include <dinput.h>
#pragma comment(lib, "dxguid.lib")
#pragma comment(lib, "dinput8.lib")

class CKeyboardHandler
{
public:
	CKeyboardHandler();
	~CKeyboardHandler();
	bool Initialize( HWND windowHandle ); // make sure to call this in the OnInitDialog() 
										// function of your main window.  pass it "this->m_hWnd"
	void PollKeyboardState();			// call this first in OnTimer()
	bool KeyDown( int key );			// use the enumerator found in DirectInput.  ie - DIK_LEFT 
										// for left arrow.  See directinput docs
private:
	LPDIRECTINPUT8 fDI;					// root direct input interface
	LPDIRECTINPUTDEVICE8 fDIKeyboard;	// the keyboard device
	char fDIKeyboardState[256];			// This will hold the entire keyboard state after it has been retrieved.

};
